[Date Prev][Date Next][Thread Prev][Thread Next][Date Index][Thread Index]
42/100: gnu: ruby-tilt: Update to 2.0.11.
From: |
guix-commits |
Subject: |
42/100: gnu: ruby-tilt: Update to 2.0.11. |
Date: |
Mon, 10 Jul 2023 03:27:32 -0400 (EDT) |
cbaines pushed a commit to branch master
in repository guix.
commit b35bd82a80b20ce4061a007e1ef8035c3be27879
Author: Christopher Baines <mail@cbaines.net>
AuthorDate: Wed Jun 28 08:25:51 2023 +0100
gnu: ruby-tilt: Update to 2.0.11.
* gnu/packages/ruby.scm (ruby-tilt): Update to 2.0.11.
[arguments]: Update style, patch some tests, remove more gems from the
Gemfile, and set SASS_IMPLEMENTATION to sassc.
---
gnu/packages/ruby.scm | 58 ++++++++++++++++++++++++++++++++-------------------
1 file changed, 37 insertions(+), 21 deletions(-)
diff --git a/gnu/packages/ruby.scm b/gnu/packages/ruby.scm
index 4c536ff828..306e3699d6 100644
--- a/gnu/packages/ruby.scm
+++ b/gnu/packages/ruby.scm
@@ -7061,7 +7061,7 @@ intended for use with event loops such as async.")
(define-public ruby-tilt
(package
(name "ruby-tilt")
- (version "2.0.10")
+ (version "2.0.11")
(source
(origin
(method git-fetch) ;the distributed gem lacks tests
@@ -7071,28 +7071,44 @@ intended for use with event loops such as async.")
(file-name (git-file-name name version))
(sha256
(base32
- "0adb7fg7925n2rd9a8kkqz3mgylw2skp9hkh9qc1rnph72mqsm6r"))))
+ "0a75s6ci2rwai5q1bnlqbz8kxqnfp2497jhkcry1n4g29lcxq9ja"))))
(build-system ruby-build-system)
(arguments
- '(#:phases
- (modify-phases %standard-phases
- (add-after 'unpack 'remove-some-dependencies
- (lambda _
- (substitute* "Gemfile"
- ;; TODO ronn is used for generating the manual
- (("gem 'ronn'.*") "\n")
- ;; ruby-haml has a runtime dependency on ruby-tilt, so don't
- ;; pass it in as a native-input
- (("gem 'haml'.*") "\n")
- ;; TODO Not all of these gems are packaged for Guix yet:
- ;; less, coffee-script, livescript, babel-transpiler,
- ;; typescript-node
- (("if can_execjs") "if false")
- ;; Disable the secondary group to reduce the number of
- ;; dependencies. None of the normal approaches work, so patch
- ;; the Gemfile instead.
- (("group :secondary") "[].each"))
- #t)))))
+ (list
+ #:phases
+ #~(modify-phases %standard-phases
+ (add-after 'unpack 'patch-tests
+ (lambda _
+ ;; Patch some tests
+ (substitute* "test/tilt_sasstemplate_test.rb"
+ (("}\",") "}
+\","))))
+ (add-after 'unpack 'remove-some-dependencies
+ (lambda _
+ (substitute* "Gemfile"
+ (("gem 'less'") "\n")
+ (("gem 'coffee-script'") "\n")
+ (("gem 'livescript'") "\n")
+ (("gem 'babel-transpiler'") "\n")
+ (("gem 'typescript-node'") "\n")
+ (("gem 'typescript-node'") "\n")
+ (("gem 'duktape'.*") "\n")
+ ;; TODO ronn is used for generating the manual
+ (("gem 'ronn'.*") "\n")
+ ;; ruby-haml has a runtime dependency on ruby-tilt, so don't
+ ;; pass it in as a native-input
+ (("gem 'haml'.*") "\n")
+ ;; TODO Not all of these gems are packaged for Guix yet:
+ ;; less, coffee-script, livescript, babel-transpiler,
+ ;; typescript-node
+ (("if can_execjs") "if false")
+ ;; Disable the secondary group to reduce the number of
+ ;; dependencies. None of the normal approaches work, so patch
+ ;; the Gemfile instead.
+ (("group :secondary") "[].each"))))
+ (add-before 'check 'set-SASS_IMPLEMENTATION
+ (lambda _
+ (setenv "SASS_IMPLEMENTATION" "sassc"))))))
(propagated-inputs
(list ruby-pandoc-ruby ruby-sassc))
(native-inputs
- 99/100: gnu: ruby-safe-yaml: Fix build., (continued)
- 99/100: gnu: ruby-safe-yaml: Fix build., guix-commits, 2023/07/10
- 32/100: gnu: ruby-term-ansicolor: Fix build., guix-commits, 2023/07/10
- 70/100: gnu: ruby-spy: Remove ruby-pry-byebug input., guix-commits, 2023/07/10
- 89/100: gnu: ruby-chunky-png: Update to 1.4.0., guix-commits, 2023/07/10
- 93/100: gnu: ruby-version-gem: Update to 1.1.3., guix-commits, 2023/07/10
- 22/100: gnu: ruby-hoe: Update to 4.0.4., guix-commits, 2023/07/10
- 25/100: gnu: ruby-tzinfo-data: Update to 1.2023.3., guix-commits, 2023/07/10
- 28/100: gnu: ruby-minitest: Update to 5.18.1., guix-commits, 2023/07/10
- 39/100: gnu: ruby-hoe: Fix build., guix-commits, 2023/07/10
- 37/100: gnu: Add ruby-http-accept-1., guix-commits, 2023/07/10
- 42/100: gnu: ruby-tilt: Update to 2.0.11.,
guix-commits <=
- 53/100: gnu: zsh-autosuggestions: Remove ruby-byebug dependency., guix-commits, 2023/07/10
- 57/100: gnu: ruby-wapiti: Update to 2.1.0., guix-commits, 2023/07/10
- 55/100: gnu: ruby-hydra: Fix build., guix-commits, 2023/07/10
- 59/100: gnu: ruby-rb-inotify: Update to 0.10.1., guix-commits, 2023/07/10
- 74/100: gnu: ruby-net-scp: Fix build., guix-commits, 2023/07/10
- 81/100: gnu: ruby-ruby-parser: Update to 3.20.2., guix-commits, 2023/07/10
- 69/100: gnu: ruby-language-server-protocol: Remove ruby-pry-byebug dependency., guix-commits, 2023/07/10
- 71/100: gnu: ruby-net-http-digest-auth: Fix build., guix-commits, 2023/07/10
- 79/100: gnu: ruby-byebug: Fix build., guix-commits, 2023/07/10
- 78/100: gnu: swagger-diff: Update to 2.0.0., guix-commits, 2023/07/10